@@ -35,6 +35,9 @@ import devede_dialogs
 import devede_convert
 import devede_help
 
+if (sys.platform=="win32") or (sys.platform=="win64"):
+	import win32api
+
 class main_window:
 	
 	def __init__(self,global_vars,callback):
@@ -45,7 +48,7 @@ class main_window:
 		self.tree=devede_other.create_tree(self,"wmain",self.gladefile)
 		self.window=self.tree.get_object("wmain")
 
-		if sys.platform=="win32":
+		if (sys.platform=="win32") or (sys.platform=="win64"):
 			self.window.drag_dest_set(0,[],0)
 			self.window.connect('drag_drop', self.drop_cb)
 		else:
@@ -115,6 +118,7 @@ class main_window:
 		self.global_vars["erase_files"]=True
 		self.global_vars["struct_name"]=""
 		self.global_vars["do_menu"]=True
+		self.global_vars["with_menu"]=True
 		self.global_vars["menu_bg"]=os.path.join(self.global_vars["path"],"backgrounds","default_bg.png")
 		self.global_vars["menu_sound"]=os.path.join(self.global_vars["path"],"silence.ogg")
 		test=devede_newfiles.file_get_params()
@@ -165,6 +169,12 @@ class main_window:
 		else:
 			w.show()
 		
+		w = self.tree.get_object("include_menu")
+		if (self.disctocreate == "dvd"):
+			w.show()
+		else:
+			w.hide()
+		
 		w1 = self.tree.get_object("frame1") # contains the titles
 		w2 = self.tree.get_object("create_dvd") # toggle to create the DVD structure
 		w5 = self.tree.get_object("menuoptions") # button to show the menu options
@@ -276,7 +286,10 @@ class main_window:
 	def get_cores(self):
 		
 		""" Returns the number of cores available in the system """
-		
+		if (sys.platform=="win32") or (sys.platform=="win64"):
+			logical_cores = win32api.GetSystemInfo()[5] #Logical Cores
+			return logical_cores
+
 		try:
 			proc=open("/proc/cpuinfo","r")
 		except:
@@ -472,6 +485,16 @@ class main_window:
 		self.set_video_values()
 	
 	
+	def on_include_menu_toggled(self,widget):
+		
+		w1=self.tree.get_object("menuoptions")
+		w2=self.tree.get_object("menu_preview")
+		status=widget.get_active()
+		w1.set_sensitive(status)
+		w2.set_sensitive(status)
+		self.global_vars["with_menu"]=status
+	
+	
 	def on_main_go_clicked(self,widget):
 
 		total=0
@@ -731,6 +754,10 @@ class main_window:
 		else:
 			w=self.tree.get_object("default_ntsc")
 		w.set_active(True)
+		
+		w=self.tree.get_object("include_menu")
+		print"Con menu: "+str(self.global_vars["with_menu"])
+		w.set_active(self.global_vars["with_menu"])
 		load=None
 
 	
