@@ -93,7 +93,7 @@ class file_get_params(devede_executor.executor):
 		else:
 			nframes=1
 
-		if sys.platform=='win32':
+		if (sys.platform=="win32") or (sys.platform=="win64"):
 			command="mplayer.exe"
 		else:
 			command="mplayer"
@@ -351,9 +351,12 @@ class newfile(file_get_params):
 		self.file_properties["gop12"]=True # GOP of 12 by default to increase compatibility
 		self.file_properties["filesize"]=os.stat(filename)[stat.ST_SIZE] # file size
 		self.file_properties["trellis"]=True # use trellis
+		self.file_properties["twopass"]=False # two pass encoding
+		self.file_properties["turbo1stpass"]=False # use turbo 1st pass on two pass encoding
 		self.file_properties["mbd"]=2 # maximum quality
 		self.file_properties["deinterlace"]="none" # don't deinterlace
 		self.file_properties["sub_list"]=[]
+		self.file_properties["force_subs"]=False
 
 		resx,resy,use_widescreen,vrate,arate=self.get_recomended_resolution(5001, 224, 0)
 		self.file_properties["width"]=resx
@@ -370,6 +373,8 @@ class newfile(file_get_params):
 		else:
 			self.file_properties["aspect"]=1.3333333
 			
+		self.file_properties["volume"]=100
+			
 		return True,audio_tracks
 
 
@@ -382,7 +387,7 @@ class newfile(file_get_params):
 		tempo=""
 		mode=0
 		
-		if sys.platform=="win32":
+		if (sys.platform=="win32") or (sys.platform=="win64"):
 			length=8
 		else:
 			length=7
@@ -533,7 +538,7 @@ class file_properties(newfile):
 		w=self.tree.get_object("moviefile")
 		self.file_filter_videos=gtk.FileFilter()
 		self.file_filter_videos.set_name(_("Video files"))
-		if sys.platform!="win32":
+		if (sys.platform!="win32") and (sys.platform!="win64"):
 			self.file_filter_videos.add_mime_type("video/*")
 			self.file_filter_videos.add_pattern("*.rmvb")
 		else:
@@ -632,6 +637,9 @@ class file_properties(newfile):
 			self.file_properties["audio_stream"]=self.file_properties["audio_list"][pos]
 			
 
+		w=self.tree.get_object("force_subs")
+		self.file_properties["force_subs"]=w.get_active()
+		
 		w=self.tree.get_object("blackbars")
 		if w.get_active():
 			self.file_properties["blackbars"]=0
@@ -641,6 +649,12 @@ class file_properties(newfile):
 		w=self.tree.get_object("trell")
 		self.file_properties["trellis"]=w.get_active()
 	
+		w=self.tree.get_object("twopass")
+		self.file_properties["twopass"]=w.get_active()
+		
+		w=self.tree.get_object("turbo1stpass")
+		self.file_properties["turbo1stpass"]=w.get_active()
+	
 		self.file_properties["mbd"]=0
 		w=self.tree.get_object("mbd1")
 		if w.get_active():
@@ -700,6 +714,9 @@ class file_properties(newfile):
 		self.file_properties["vrate"]=int(w.get_value())
 		w=self.tree.get_object("audio_rate")
 		self.file_properties["arate"]=int(w.get_value())
+		
+		w=self.tree.get_object("volume_adj")
+		self.file_properties["volume"]=int(w.get_value())
 	
 		w=self.tree.get_object("full_length")
 		if w.get_active():
@@ -761,9 +778,14 @@ class file_properties(newfile):
 
 	# Callbacks
 	
+	def on_reset_volume_clicked(self,widget):
+		w=self.tree.get_object("volume_adj")
+		w.set_value(100)
+		
+	
 	def on_sub_add_clicked(self,widget):
 		
-		window=ask_subtitle(self.gladefile,self.global_vars["filmpath"])
+		window=ask_subtitle(self.gladefile,self.global_vars["filmpath"],self.global_vars)
 		ret=window.run()
 		window=None
 		if ret!=None:
@@ -945,7 +967,14 @@ class file_properties(newfile):
 		self.set_film_buttons()
 		self.set_global_values()
 
-
+	def on_twopass_toggled(self,widget):
+		w = self.tree.get_object("turbo1stpass")
+		if widget.get_active():
+			w.set_sensitive(True)
+		else:
+			w.set_active(False)
+			w.set_sensitive(False)
+			
 	def on_sound51_toggled(self,widget):
 
 		self.set_film_buttons()
@@ -1003,7 +1032,7 @@ class file_properties(newfile):
 					if (current_file=="") or (current_file==None):
 						devede_dialogs.show_error(self.gladefile,_("Please, add a movie file before adding subtitles."))
 						return
-					window=ask_subtitle(self.gladefile,self.global_vars["filmpath"],lista[0])
+					window=ask_subtitle(self.gladefile,self.global_vars["filmpath"],self.global_vars,lista[0])
 					ret=window.run()
 					window=None
 					if ret!=None:
@@ -1061,7 +1090,9 @@ class file_properties(newfile):
 			w.set_upper(384)
 			#w.set_range(64,384)
 		else:
+			print "entro en parte critica"
 			w=self.tree.get_object("audio_rate_adj")
+			print "paso por set_lower"
 			w.set_lower(128)
 			w.set_upper(448)
 			#w.set_range(128,448)
@@ -1074,10 +1105,15 @@ class file_properties(newfile):
 
 		if self.file_properties==None:
 			return
+		
+		w=self.tree.get_object("force_subs")
+		w.set_active(self.file_properties["force_subs"])
 
 		w1=self.tree.get_object("aspect_ratio_4_3")
 		w2=self.tree.get_object("aspect_ratio_16_9")
 		w1.set_active(True)
+		print "Activo ASPECT_RATIO"
+		print self.disctocreate
 		if (self.disctocreate=="dvd") or (self.disctocreate=="divx"):
 			w1.set_sensitive(True)
 			w2.set_sensitive(True)
@@ -1113,6 +1149,12 @@ class file_properties(newfile):
 		w=self.tree.get_object("trell")
 		w.set_active(self.file_properties["trellis"])
 	
+		w=self.tree.get_object("twopass")
+		w.set_active(self.file_properties["twopass"])
+		
+		w=self.tree.get_object("turbo1stpass")
+		w.set_active(self.file_properties["turbo1stpass"])
+		
 		if self.file_properties["mbd"]==0:
 			w=self.tree.get_object("mbd")
 		elif self.file_properties["mbd"]==1:
@@ -1127,6 +1169,9 @@ class file_properties(newfile):
 			w=self.tree.get_object("deinterlace_"+self.file_properties["deinterlace"])
 		w.set_active(True)
 	
+		w=self.tree.get_object("volume_adj")
+		w.set_value(self.file_properties["volume"])
+	
 		w=self.tree.get_object("ismpeg")
 		w.set_active(self.file_properties["ismpeg"])
 
@@ -1277,19 +1322,22 @@ class file_properties(newfile):
 			w1.set_sensitive(True)
 
 		w0=self.tree.get_object("ismpeg")
-		if w0.get_active():
+		w0s=w0.get_active()
+		if w0s:
 			grupo2=False
 		else:
 			grupo2=True
 
 		w1=self.tree.get_object("copy_audio")
-		if w1.get_active():
+		w1s=w1.get_active()
+		if w1s:
 			copy_audio=False
 		else:
 			copy_audio=grupo2
 
 		w2=self.tree.get_object("isvob")
-		if w2.get_active():
+		w2s=w2.get_active()
+		if w2s:
 			isvob=False
 		else:
 			isvob=grupo2
@@ -1302,22 +1350,22 @@ class file_properties(newfile):
 			w1.set_sensitive(grupo2)
 			sound51=grupo2
 
-		if w0.get_active():
-			w1.set_sensitive(False)
+		if w0s:
 			w2.set_sensitive(False)
-		else:
-			w1.set_sensitive(True)
-			w2.set_sensitive(True)
-
-		if w1.get_active():
-			w2.set_sensitive(False)
-		else:
-			w2.set_sensitive(True)
-
-		if w2.get_active():
 			w1.set_sensitive(False)
 		else:
+			w2.set_sensitive(True)
 			w1.set_sensitive(True)
+			if w1s:
+				w2.set_sensitive(False)
+			else:
+				w2.set_sensitive(True)
+				if w2s:
+					w0.set_sensitive(False)
+					w1.set_sensitive(False)
+				else:
+					w1.set_sensitive(True)
+					w0.set_sensitive(True)
 
 		if self.disctocreate =="vcd":
 			grupo1=False
@@ -1328,10 +1376,10 @@ class file_properties(newfile):
 			w=self.tree.get_object("sound51")
 			if w.get_active():
 				w=self.tree.get_object("audio_rate_adj")
-				w.set_lower(348)
+				w.set_lower(384)
 				w.set_upper(448)
-				if w.get_value()<348:
-					w.set_value(348)
+				if w.get_value()<384:
+					w.set_value(384)
 				#w.set_range(384,448)		
 			else:
 				w=self.tree.get_object("audio_rate_adj")
@@ -1354,13 +1402,19 @@ class file_properties(newfile):
 		w.set_sensitive(grupo1 and isvob)
 		w=self.tree.get_object("gop12")
 		w.set_sensitive(grupo2 and isvob)
+		w=self.tree.get_object("volume_scale")
+		w.set_sensitive(grupo2 and isvob and copy_audio)
+		w=self.tree.get_object("volume_level")
+		w.set_sensitive(grupo2 and isvob and copy_audio)
+		w=self.tree.get_object("reset_volume")
+		w.set_sensitive(grupo2 and isvob and copy_audio)
 		w=self.tree.get_object("sound51")
 		if grupo1==False:
 			w.set_active(False)
 		w.set_sensitive(sound51)
 		w=self.tree.get_object("resauto")
 		w.set_sensitive(grupo1 and isvob)
-		if w.get_active():
+		if (w.get_active()) and (self.disctocreate=="divx"):
 			set_aspect=False
 		else:
 			set_aspect=True
@@ -1429,6 +1483,10 @@ class file_properties(newfile):
 		w.set_sensitive(grupo2 and isvob)
 		w=self.tree.get_object("mbd2")
 		w.set_sensitive(grupo2 and isvob)
+		w=self.tree.get_object("twopass")
+		w.set_sensitive(grupo2 and isvob)
+		w=self.tree.get_object("turbo1stpass")
+		w.set_sensitive(grupo2 and isvob)
 		w=self.tree.get_object("deinterlace")
 		w.set_sensitive(grupo2 and isvob)
 		w=self.tree.get_object("deinterlace_lb")
@@ -1543,7 +1601,7 @@ class file_properties(newfile):
 			props["ismpeg"]=w3.get_active()
 			print "Props: "+str(props)
 			speed1,speed2=devede_other.get_speedup(props)
-			l=devede_other.calcula_tamano_parcial(vrate,arate,self.file_properties["filesize"],self.file_properties["olength"],len(self.file_properties["sub_list"]),w2.get_active(),w4.get_active,divide2,speed1,speed2)
+			l=devede_other.calcula_tamano_parcial(vrate,arate,self.file_properties["filesize"],self.file_properties["olength"],len(self.file_properties["sub_list"]),w2.get_active(),w4.get_active(),divide2,speed1,speed2)
 			#if w2.get_active():
 			#	l=int(self.file_properties["filesize"]/1000000)
 			#else:
@@ -1563,38 +1621,56 @@ class file_properties(newfile):
 
 class ask_subtitle:
 	
-	def __init__(self,gladefile,filepath,filename=None):
+	def __init__(self,gladefile,filepath,gvars,filename=None):
 
+		self.global_vars=gvars
 		self.gladefile=gladefile
 		self.tree=devede_other.create_tree(self,"add_subtitle2",self.gladefile)
 		self.lang_list=[]
 		self.cpage_list=[]
 		
 		pos=0
-		chelement=0
+		self.lang=-1
+		self.asciie=-1
+		self.utf8e=-1
+		self.utf16e=-1
+		self.isoe=-1
 		languages=open(os.path.join(self.gladefile,"languages.lst"),"r")
 		w=self.tree.get_object("sub_language")
 		for element in languages:
-			if element[:-1]=="EN (ENGLISH)":
-				chelement=pos
+			if element[:-1]==self.global_vars["sub_language"]:
+				self.lang=pos
 			w.append_text(element[:-1])
 			self.lang_list.append(element[:-1])
 			pos+=1
 		languages.close()
-		w.set_active(chelement)
+		w.set_active(self.lang)
 		
 		pos=0
-		chelement=0
+		self.chelement=0
 		codepages=open(os.path.join(self.gladefile,"codepages.lst"),"r")
 		w=self.tree.get_object("sub_codepage")
 		for element in codepages:
+			if element[:-1]=="ASCII":
+				self.asciie=pos
+			if element[:-1]=="UTF-8":
+				self.utf8e=pos
+			if element[:-1]=="UTF-16":
+				self.utf16e=pos
 			if element[:-1]=="ISO-8859-1":
-				chelement=pos
+				self.isoe=pos
+			if element[:-1]==self.global_vars["sub_codepage"]:
+				self.chelement=pos
 			w.append_text(element[:-1])
 			self.cpage_list.append(element[:-1])
 			pos+=1
 		codepages.close()
-		w.set_active(chelement)
+		if self.chelement!=-1:
+			w.set_active(self.chelement)
+		elif (self.utf8e!=-1):
+			w.set_active(self.utf8e)
+		else:
+			w.set_active(self.isoe)
 
 		self.window=self.tree.get_object("add_subtitle")
 		if (filepath!=""):
@@ -1614,9 +1690,29 @@ class ask_subtitle:
 
 	def on_subtitles_chooser_selection_changed(self,widget):
 		
+		filename=widget.get_filename()
+		if (filename!="") and (filename!=None):
+			w=self.tree.get_object("sub_codepage")
+			autotype=devede_other.check_utf().do_check(filename)
+			print "Subtitles changed to type: "+str(autotype)
+			if autotype=="ascii":
+				w.set_active(self.asciie)
+				self.autotype="ASCII"
+			elif autotype=="utf8":
+				w.set_active(self.utf8e)
+				self.autotype="UTF-8"
+			elif autotype=="utf16":
+				w.set_active(self.utf16e)
+				self.autotype="UTF-16"
+			elif self.chelement!=-1:
+				w.set_active(self.chelement)
+				self.autotype=""
+			else:
+				w.set_active(self.isoe)
+				self.autotype=""
 		self.set_status()
 
-	
+
 	def set_status(self):
 		
 		filename=self.tree.get_object("subtitles_chooser").get_filename()
@@ -1639,8 +1735,11 @@ class ask_subtitle:
 			ret_val["subtitles"]=w.get_filename()
 			w=self.tree.get_object("sub_codepage")
 			ret_val["sub_codepage"]=self.cpage_list[w.get_active()]
+			if (ret_val["sub_codepage"]!=self.autotype) and (ret_val["sub_codepage"][:3]!="UTF"):
+				self.global_vars["sub_codepage"]=ret_val["sub_codepage"]
 			w=self.tree.get_object("sub_language")
 			ret_val["sub_language"]=self.lang_list[w.get_active()]
+			self.global_vars["sub_language"]=ret_val["sub_language"]
 			w=self.tree.get_object("sub_up")
 			ret_val["subtitles_up"]=w.get_active()
 		else:
