@@ -1,6 +1,5 @@
-#!/usr/local/bin/python2.5
+#!/usr/local/bin/python2.6
 # -*- coding: UTF-8 -*-
-
 # Copyright 2006-2009 (C) Raster Software Vigo (Sergio Costas)
 # Copyright 2006-2009 (C) Peter Gill - win32 parts
 
@@ -39,7 +38,7 @@ import gtk
 import devede_other
 import gobject
 import cairo
-if sys.platform=='win32':
+if (sys.platform=="win32") or (sys.platform=="win64"):
 	import win32api
 
 import devede_other
@@ -96,7 +95,7 @@ class create_all:
 		if iso_name.get_text()=="":
 			mode=False
 		
-		folder=iso_folder.get_filename()
+		folder=iso_folder.get_current_folder()
 		if folder==None:
 			mode=False
 		elif folder=="":
@@ -112,7 +111,7 @@ class create_all:
 		# TODO Windows Stuff
 		estado=''
 		freespace=''
-		if sys.platform!='win32':
+		if (sys.platform!="win32") and (sys.platform!="win64"):
 			print "Checking "+str(filefolder)
 			estado=os.statvfs(filefolder) # eg. f="C:\Documents and Settings\User name\Desktop"
 			freespace=95*estado.f_bsize*estado.f_bavail/100000
@@ -181,11 +180,23 @@ class create_all:
 		for element in self.structure:
 			chapter=0
 			for element2 in element[1:]:
-				self.queue.append(["C",title,chapter])
+				if self.structure[title][chapter+1]["twopass"] == True:
+					self.queue.append(["C1",title,chapter])
+					self.queue.append(["C2",title,chapter])
+				else:
+					self.queue.append(["C",title,chapter])
 				stream=0
 				for element3 in element2["sub_list"]:
 					self.queue.append(["S",title,chapter,stream])
 					stream+=1
+
+				#if self.structure[title][chapter+1]["twopass"] == True:
+				#	self.queue.append(["C2",title,chapter])
+				#	stream=0
+				#	for element3 in element2["sub_list"]:
+				#		self.queue.append(["S",title,chapter,stream])
+				#		stream+=1
+						
 				chapter+=1
 			title+=1
 
@@ -236,6 +247,11 @@ class create_all:
 		return self.filefolder
 		
 
+	def on_iso_filename_activate(self,widg,ventana):
+		
+		ventana.response(-6)
+
+
 	def create_disc(self):
 		
 		self.time=0
@@ -262,22 +278,34 @@ class create_all:
 		
 		newtree=devede_other.create_tree(self,"wfolder_dialog",self.gladefile,False)
 		wdir=newtree.get_object("final_directory")
+		if self.global_vars["finalfolder"]!="":
+			wdir.set_current_folder(self.global_vars["finalfolder"])
 		wfile=newtree.get_object("iso_filename")
+		wfolder_dialog=newtree.get_object("wfolder_dialog")
 		wfile.set_text("movie")
+		wfile.connect("activate",self.on_iso_filename_activate,wfolder_dialog)
 		wfile.connect("changed",self.iso_changed,newtree)
-		self.iso_changed("",newtree)
-		w=newtree.get_object("wfolder_dialog")
-		w.show()
-		value=w.run()
+		wdir.connect("current-folder-changed",self.iso_changed,newtree)
+		#self.iso_changed("",newtree)
+
+		wfolder_dialog.show()
+		wfile.grab_focus()
+		value=wfolder_dialog.run()
 		
 		self.filename=wfile.get_text()
-		filefolder=wdir.get_filename()
+		self.filename.replace("/","_")
+		self.filename.replace("|","_")
+		self.filename.replace("\\","_")
+			
+		filefolder=wdir.get_current_folder()
 		
-		w.hide()
-		w.destroy()
+		wfolder_dialog.hide()
+		wfolder_dialog.destroy()
 		if value!=-6:
 			return False
 		
+		self.global_vars["finalfolder"]=filefolder
+		
 		filefolder2=os.path.join(filefolder,self.filename)
 		
 		self.filefolder=filefolder2
@@ -327,11 +355,12 @@ class create_all:
 		counter=0
 		counter2=0
 		if (self.disk_type=="dvd"):
-			nelements=xml_files.get_elements_per_menu()
-			while (len(self.structure[counter:])!=0):
-				self.queue.append(["M1",xml_files,counter,counter2])
-				counter+=nelements
-				counter2+=1
+			if xml_files.do_menus():
+				nelements=xml_files.get_elements_per_menu()
+				while (len(self.structure[counter:])!=0):
+					self.queue.append(["M1",xml_files,counter,counter2])
+					counter+=nelements
+					counter2+=1
 
 		self.init_queue()
 
@@ -368,13 +397,16 @@ class create_all:
 		self.total.set_text(str(self.current_action)+"/"+str(len(self.queue)-1))
 		self.total.set_fraction(float(self.current_action)/(float(len(self.queue)-1)))
 		if self.runner!=None:
-			retval=self.runner.refresh()
+			if self.runner.initerror:
+				retval=-1;
+			else:
+				retval=self.runner.refresh()
 			if retval==0: # no error, still running
 				return True
 			else:
 				self.current_action+=1
 				retval=self.runner.wait_end()
-				if retval!=0:
+				if (retval!=0) or (self.runner.initerror):
 					self.window.hide()
 					self.window.destroy()
 					if self.runner.print_error==None:
@@ -393,10 +425,21 @@ class create_all:
 			self.runner.create_menu1(action[2],action[3],self.global_vars["multicore"])
 			return True
 		
-		if action[0]=="C":
+		if action[0][0]=='C':
 			title=action[1]
 			chapter=action[2]
-			self.runner=devede_video_convert.video_converter(self.structure[title][chapter+1],self.filename,self.filefolder,self.partial,self.label,self.global_vars["disctocreate"],title+1,chapter+1,self.global_vars["multicore"],self.seconds)
+			if action[0]=="C":
+				encpass = 0
+			else:
+				encpass = int(action[0][1])
+			print "Segundos "+str(self.seconds)
+			self.runner=devede_video_convert.video_converter(self.global_vars,self.structure[title][chapter+1],self.filename,self.filefolder,self.partial,self.label,self.global_vars["disctocreate"],title+1,chapter+1,self.global_vars["multicore"],self.seconds, encpass)
+			return True
+		
+		if action[0]=="C2":
+			title=action[1]
+			chapter=action[2]
+			self.runner=devede_video_convert.video_converter(self.structure[title][chapter+1],self.filename,self.filefolder,self.partial,self.label,self.global_vars["disctocreate"],title+1,chapter+1,self.global_vars["multicore"],self.seconds, 2)
 			return True
 		
 		if action[0]=="S":
@@ -409,7 +452,7 @@ class create_all:
 		if action[0]=="PREVIEW":
 			self.window.hide()
 			self.window.destroy()
-			if sys.platform=='win32':
+			if (sys.platform=="win32") or (sys.platform=="win64"):
 				mplay="mplayer.exe"
 			else:
 		 		mplay="mplayer"
