@@ -1,4 +1,4 @@
-#!/usr/local/bin/python2.5
+#!/usr/local/bin/python2.6
 # -*- coding: UTF-8 -*-
 
 # Copyright 2006-2007 (C) Raster Software Vigo (Sergio Costas)
@@ -45,6 +45,7 @@ class delete_files:
 		self.delete_menu_temp()
 		self.delete_menu()
 		self.delete_mpg()
+		self.delete_log()
 		self.delete_sub_xml()
 		self.delete_xml()
 		self.delete_main_dir()
@@ -64,7 +65,16 @@ class delete_files:
 		except OSError:
 			print self.filepath+"._??_??.mpg not found"
 	
-			
+	
+	def delete_log(self):
+
+		print "Deleting "+self.filename+".log"
+		try:
+			os.remove(self.filename+".log")
+		except OSError:
+			print self.filepath+".log not found"
+	
+	
 	def delete_avi(self):
 
 		try:
@@ -161,12 +171,17 @@ class delete_files:
 			print "Can't delete "+self.filepath+"_menu2_?.mpg"
 
 
-	def delete_sub_xml(self):
+	def delete_sub_xml(self,xtrasub=""):
 
 		try:
 			os.remove(self.filepath+"_sub.xml")
 		except OSError:
 			print self.filepath+".xml not found"
+		if xtrasub!="":
+			try:
+				os.remove(xtrasub)
+			except OSError:
+				print str(xtrasub)+" not found"
 		
 	
 	def delete_iso(self):
