@@ -1,4 +1,4 @@
-#!/usr/local/bin/python2.5
+#!/usr/local/bin/python2.6
 # -*- coding: UTF-8 -*-
 
 # Copyright 2006-2009 (C) Raster Software Vigo (Sergio Costas)
@@ -112,7 +112,7 @@ class load_save_config:
 					not_found.append(str(element2["path"]))
 					continue
 				
-				if False==element2.has_key("copy_sound"):
+				if False==element2.has_key("copy_audio"):
 					element2["copy_audio"]=False # for backward compatibility
 				if False==element2.has_key("sound51"):
 					element2["sound51"]=False # for backward compatibility
@@ -128,8 +128,16 @@ class load_save_config:
 					element2["isvob"]=False # for backward compatibility
 				if False==element2.has_key("swap_fields"):
 					element2["swap_fields"]=False # for backward compatibility
+				if False==element2.has_key("twopass"):
+					element2["twopass"]=False # for backward compatibility
+				if False==element2.has_key("turbo1stpass"):
+					element2["turbo1stpass"]=False # for backward compatibility
 				if False==element2.has_key("subfont_size"):
-					self.file_properties["subfont_size"]=28 # subtitle font size
+					element2["subfont_size"]=28 # subtitle font size
+				if False==element2.has_key("volume"):
+					element2["volume"]=100 # default volume (in percentage)
+				if False==element2.has_key("force_subs"):
+					element2["force_subs"]=False # by default, subtitles aren't forced
 				
 				if False==element2.has_key("audio_stream"):
 					fileprop=devede_newfiles.newfile("","")
@@ -150,6 +158,7 @@ class load_save_config:
 						del element2["subtitles"]
 						del element2["sub_codepage"]
 						del element2["subtitles_up"]
+						element2["sub_list"].append(tmp)
 				
 	
 		if len(not_found)!=0:
@@ -168,7 +177,7 @@ class load_save_config:
 			global_vars2["menu_bg"]=os.path.join(self.global_vars["path"],"backgrounds","default_bg.png")
 			
 		use_default_sound=False
-		
+	
 		if False==global_vars2.has_key("menu_sound"):
 			use_default_sound=True
 		else:
@@ -181,6 +190,12 @@ class load_save_config:
 				w = devede_dialogs.show_error(self.gladefile,_("Can't find the menu soundtrack file. I'll open the disc structure anyway with a silent soundtrack, so don't forget to fix it before creating the disc."))
 				w = None
 		
+		if (use_default_sound):
+			global_vars2["menu_sound"]=os.path.join(self.global_vars["path"],"silence.ogg")
+
+		if False==global_vars2.has_key("with_menu"):
+			global_vars2["with_menu"]=True
+		
 		if False==global_vars2.has_key("menu_halignment"):
 			global_vars2["menu_halignment"]=2 # center
 			
@@ -189,9 +204,6 @@ class load_save_config:
 			
 		if False==global_vars2.has_key("menu_title_shadow"):
 			global_vars2["menu_title_shadow"]=[0,0,0,0]
-			
-		if (use_default_sound):
-			global_vars2["menu_sound"]=os.path.join(self.global_vars["path"],"silence.ogg")
 
 		test=devede_newfiles.file_get_params()
 		check,channels=test.read_file_values(global_vars2["menu_sound"],True)
@@ -281,6 +293,7 @@ class load_save_config:
 			vars["disctocreate"]=self.global_vars["disctocreate"]
 			vars["titlecounter"]=self.global_vars["titlecounter"]
 			vars["do_menu"]=self.global_vars["do_menu"]
+			vars["with_menu"]=self.global_vars["with_menu"]
 			vars["menu_widescreen"]=self.global_vars["menu_widescreen"]
 			vars["PAL"]=self.global_vars["PAL"]
 			vars["menu_bg"]=self.global_vars["menu_bg"]
