@@ -1,4 +1,4 @@
-#!/usr/local/bin/python2.5
+#!/usr/local/bin/python2.6
 # -*- coding: UTF-8 -*-
 
 # Copyright 2006-2009 (C) Raster Software Vigo (Sergio Costas)
@@ -31,9 +31,261 @@ import sys
 import shutil
 import cairo
 import gtk
+import struct
+
+import devede_executor
+
+
+class check_utf(devede_executor.executor):
+	
+	""" This class allows to detect if a file is pure ASCII, UTF-8 or UTF-16, and allows
+		to convert from UTF-16 to UFT-8 """
+	
+	def check_ascii(self,filename):
+		
+		try:
+			file=open(filename,"rb")
+		except:
+			return False
+		
+		while True:
+			element=file.read(1)
+			if len(element)==0:
+				return True
+			if ord(element)>127:
+				return False
+	
+
+	def read_utf8_element(self,file,base_value,nb):
+		
+		value=base_value
+		for counter in range(nb-1):
+			element=file.read(1)
+			if element=="":
+				return False
+			if (ord(element)>191) or (ord(element)<128):
+				return False
+			value*=64 # rotate value 6 bits to the left
+			value+=ord(element)-128
+		return value
+
+	
+	def check_utf8(self,filename):
+		
+		try:
+			file=open(filename,"rb")
+		except:
+			return False
+		
+		while True:
+			el=file.read(1)
+			if el=="":
+				file.close()
+				return True
+			element=ord(el)
+	
+			if element<128:
+				continue
+			
+			if element<194: # it's a mid-sequence element or a 2-byte start sequence for an element smaller than 128
+				print "Elemento 1"
+				file.close()
+				return False # invalid element found
+			
+			if element<224: # two-byte element
+				value=self.read_utf8_element(file,element-192, 2)
+				if value==False:
+					print "Elemento 2"
+					file.close()
+					return False # invalid sequence
+				if value<128:
+					print "Elemento 3"
+					file.close()
+					return False # invalid value for a 2-byte sequence
+				continue
+				
+			if element<240: # three-byte element
+				value=self.read_utf8_element(file,element-224, 3)
+				if value==False:
+					print "Elemento 4"
+					file.close()
+					return False # invalid sequence
+				if value<2048:
+					print "Elemento 5"
+					file.close()
+					return False # invalid value for a 3-byte sequence
+				continue
+			
+			if element<245: # four-byte element
+				value=self.read_utf8_element(file,element-240, 4)
+				if value==False:
+					print "Elemento 6"
+					file.close()
+					return False # invalid sequence
+				if value<65536:
+					print "Elemento 7"
+					file.close()
+					return False # invalid value for a 4-byte sequence
+				continue
+			
+			file.close()
+			return False # invalid value
+
+
+	def read_16(self,file,format_b):
+		element=file.read(2)
+		if element=="":
+			return ""
+		if len(element)!=2:
+			return False
+		value=struct.unpack(format_b,element)[0]
+		return value
+
+	
+	def read_full16(self,file,format_b):
+		value=self.read_16(file, format_b)
+		if value=="":
+			return True # end of file
+		if value==False:
+			return False
+		if (value>=56320) and (value<=57343): # invalid value
+			return False
+		if (value>55295) and (value<56320): # surrogate pair
+			value-=55296
+			value2=self.read_16(file, format_b)
+			if (value2==False) or (value2==""):
+				return False
+			if (value2<56320) or (value2>57343): # invalid surrogate pair
+				return False
+			value2-=56320
+			return ((value*1024+value2)+65536)
+		else:
+			return value
+	
+	
+	def write_utf8(self,file,value):
+		
+		if value<128:
+			file.write(struct.pack("B",value))
+		elif value<2048:
+			v1=(value/64) & 31
+			v2= value     & 63
+			file.write(struct.pack("BB",v1+192,v2+128))
+		elif value<65536:
+			v1=(value/4096) & 15
+			v2=(value/64)   & 63
+			v3= value       & 63
+			file.write(struct.pack("BBB",v1+224,v2+128,v3+128))
+		else:
+			v1=(value/262143) & 7
+			v2=(value/4096)   & 63
+			v3=(value/64)     & 63
+			v4= value         & 63
+			file.write(struct.pack("BBBB",v1+240,v2+128,v3+128,v4+128))		   
+	
+	
+	def check_utf16BE(self,filename):
+		
+		try:
+			file=open(filename,"rb")
+		except:
+			return False
+		value=self.read_16(file, ">H")
+		file.close()
+		if value==65279:
+			return True
+		return False
+
+
+	def check_utf16LE(self,filename):
+		
+		try:
+		  file=open(filename,"rb")
+		except:
+			return False
+		value=self.read_16(file, "<H")
+		file.close()
+		if value==65279:
+			return True
+		return False
+	
+	
+	def check_utf16(self,filename,big_endian):
+		
+		try:
+			file=open(filename,"rb")
+		except:
+			return False
+		if big_endian:
+			format_b=">H"
+		else:
+			format_b="<H"
+		while True:
+			value=self.read_full16(file, format_b)
+			if value==True:
+				return True
+			if value==False:
+				return False
+			# value can be an integer too, that's why I put both IFs
+
+	
+	def convert_to_UTF8(self,infile_n,outfile_n,origin_format):
+		
+		command_line='iconv -f '+str(origin_format)+' -t UTF8 "'+str(infile_n)+'" -o "'+str(outfile_n)+'"'
+		return self.launch_shell(command_line).wait()
+	
+	
+	def convert_16_to_8(self,infile_n,outfile_n):
+		
+		if self.check_utf16BE(infile_n):
+			format_b=">H"
+		else:
+			format_b="<H"
+		
+		infile=open(infile_n,"rb")
+		outfile=open(outfile_n,"wb")
+		
+		first=True
+		while True:
+			value=self.read_full16(infile, format_b)
+			if (value==65279) and first:
+				first=False
+				continue
+			first=False
+			if (value==True) or (value==False):
+				break
+			self.write_utf8(outfile, value)
+		infile.close()
+		outfile.close()
+		return value
+	
+	
+	def do_check(self,filename):
+		
+		""" Checks if a file is pure ASCII, UTF-8, UTF-16 or Unknown """
+		
+		self.type="Unknown"
+		
+		if self.check_ascii(filename):
+			self.type="ascii"
+			return self.type
+		
+		if self.check_utf8(filename):
+			self.type="utf8"
+			return self.type
+		
+		if (self.check_utf16BE(filename)):
+			if (self.check_utf16(filename,True)):
+				self.type="utf16"
+			return self.type 
+		
+		if (self.check_utf16LE(filename)):
+			if (self.check_utf16(filename,False)):
+				self.type="utf16"
+			return self.type
+		
+		return self.type
 
-if sys.platform == 'win32':
-	import devede_executor
 
 
 def get_speedup(videofile):
@@ -152,7 +404,7 @@ def check_program(programa):
 	""" This function allows to check that a program is available in the system, just
 	by calling it without arguments and checking the error returned """
 
-	if sys.platform=='win32':
+	if (sys.platform=="win32") or (sys.platform=="win64"):
 		launcher=devede_executor.executor()
 		p=launcher.launch_program(programa,win32arg=False)
 	else:
@@ -171,7 +423,7 @@ def load_config(global_vars):
 
 	# TODO change to allow a windows temp directory
 
-	if sys.platform=='win32':
+	if (sys.platform=="win32") or (sys.platform=="win64"):
 		#global_vars["temp_folder"]=os.environ["TEMP"]
 		global_vars["temp_folder"]=os.path.join(home,"Local Settings", "Temp")
 	else:
@@ -179,7 +431,7 @@ def load_config(global_vars):
 	
 	print "Temp Directory is: " , global_vars["temp_folder"]
 	
-	if sys.platform=='win32':
+	if (sys.platform=="win32") or (sys.platform=="win64"):
 		home=os.path.join(home,"Application Data", "devede","devede.conf")
 	else:
 		home+=".devede"
@@ -208,6 +460,14 @@ def load_config(global_vars):
 				global_vars["temp_folder"]=linea[12:]
 			if linea[:10]=="multicore:":
 				global_vars["multicore"]=int(linea[10:]) # don't remember multicore
+			if linea[:13]=="final_folder:":
+				global_vars["finalfolder"]=linea[13:]
+			if linea[:13]=="sub_language:":
+				global_vars["sub_language"]=linea[13:]
+			if linea[:13]=="sub_codepage:":
+				global_vars["sub_codepage"]=linea[13:]
+			#if linea[:]==":":
+			#	global_vars[""]=linea[:]
 		archivo.close()
 	except IOError:
 		pass
@@ -219,7 +479,7 @@ def save_config(global_vars):
 
 	home=get_home_directory()
 
-	if sys.platform=='win32':
+	if (sys.platform=="win32") or (sys.platform=="win64"):
 		home=os.path.join(home,"Application Data", "devede")
 		if not os.path.isdir(home):
 			os.mkdir(home)
@@ -237,6 +497,10 @@ def save_config(global_vars):
 			archivo.write("video_format:ntsc\n")
 		archivo.write("temp_folder:"+global_vars["temp_folder"]+"\n")
 		archivo.write("multicore:"+str(global_vars["multicore"])+"\n")
+		if global_vars["finalfolder"]!="":
+			archivo.write("final_folder:"+str(global_vars["finalfolder"])+"\n")
+		archivo.write("sub_language:"+str(global_vars["sub_language"])+"\n")
+		archivo.write("sub_codepage:"+str(global_vars["sub_codepage"])+"\n")
 		archivo.close()
 	except IOError:
 		pass
@@ -290,7 +554,7 @@ def get_new_param(parameters):
 
 def get_home_directory():
 	
-	if sys.platform == 'win32':
+	if (sys.platform=="win32") or (sys.platform=="win64"):
 		home=os.environ["USERPROFILE"]
 	else:
 		home=os.environ.get("HOME")
